@@ -503,7 +503,7 @@ def bar(func):
 
 if __name__ == '__main__':
     # 将 list[dict] 数据插入excel
-    PandasPro.insert_lists_dict_to_excel([{'a': 1, 'b': 2}, {'a': 3, 'b': 4}], 'test')
+    PandasPro.insert_lists_dict_to_excel(lists=[{'a': 1, 'b': 2}, {'a': 3, 'b': 4}], table_name='test')
 
     # 将mysql数据插入excel中，数据库连接信息，默认读取环境变量 ~/.bash_profile
     PandasPro.mysql_to_execl('test')
